%define major     0
%define libname   %mklibname afflib %{major}
%define develname %mklibname afflib -d

Summary:        A set of programs for creating and manipulating AFF files
Name:           afflib
Version:        3.7.20
Release:        %mkrel 1
Group:          System/Libraries
License:        BSD
URL:            https://github.com/sshock/AFFLIBv3
Source0:        https://github.com/sshock/AFFLIBv3/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         python3.10.patch
BuildRequires:  pkgconfig(libcurl)
# GPLv2 FOSS incompatible with BSD with advertising
#BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libewf)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(openssl)

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(setuptools)
# GPLv2 FOSS incompatible with BSD with advertising
#BuildRequires:  readline-devel
BuildRequires:  pkgconfig(zlib)


%description
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

In addition to the library, AFFLIB also comes with the AFF Tools, a set of
programs for creating and manipulating AFF files.

%package -n  %{libname}
Summary:     A shared library that implements the AFF standard
Group:       System/Libraries

%description -n	%{libname}
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

This package contains a shared library that implements the AFF standard.

%package -n  %{develname}
Summary:     Static library and header files for the afflib library
Group:       Development/C
Provides:    %{name}-devel = %{version}
Requires:    %{libname} = %{version}

%description -n %{develname}
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

This package contains the static afflib library and its header files.

%prep
%autosetup -p1 -n AFFLIBv3-%{version}

#fix spurious permissions with lzma443
find lzma443 -type f -exec chmod 0644 {} ';'
chmod 0644 lib/base64.{h,cpp}

%build
sh bootstrap.sh
%configure \
               --disable-static \
               --enable-shared \
               --enable-s3=yes \
               --enable-fuse=no \
               --enable-python=yes \
               --enable-qemu=no \
               --with-curl=%{_prefix} \
               PYTHON=%{__python3}
%make_build

%install
%make_install

# install headers as well
install -d %{buildroot}%{_includedir}/afflib
install -m0644 lib/*.h %{buildroot}%{_includedir}/afflib/

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%{_bindir}/affcat
%{_bindir}/affcompare
%{_bindir}/affconvert
%{_bindir}/affcopy
%{_bindir}/affcrypto
%{_bindir}/affdiskprint
%{_bindir}/affix
%{_bindir}/affuse
%{_bindir}/affinfo
%{_bindir}/affrecover
%{_bindir}/affsegment
%{_bindir}/affsign
%{_bindir}/affstats
%{_bindir}/affverify
%{_bindir}/affxml
%{_mandir}/man1/*
%{python3_sitearch}/pyaff*.so
%{python3_sitearch}/PyAFF-*-py%{python3_version}.egg-info/

%files -n %{libname}
%doc AUTHORS BUGLIST.txt COPYING ChangeLog NEWS README* doc/*
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/afflib
%{_includedir}/afflib/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Sun Jan 08 2023 daviddavid <daviddavid> 3.7.20-1.mga9
+ Revision: 1931660
- new version: 3.7.20

* Sun Mar 27 2022 umeabot <umeabot> 3.7.19-5.mga9
+ Revision: 1829317
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 3.7.19-4.mga9
+ Revision: 1773472
- Fix building with python-3.10
- Rebuild for python-3.10

* Sat Oct 02 2021 wally <wally> 3.7.19-3.mga9
+ Revision: 1748089
- rebuild for openssl 3.0.0

* Sat Mar 20 2021 tv <tv> 3.7.19-2.mga9
+ Revision: 1705656
- Fix detecting python 3.9
- rebuild for python-3.9.2

* Tue Jul 14 2020 daviddavid <daviddavid> 3.7.19-1.mga8
+ Revision: 1606119
- new version: 3.7.19

* Sun Feb 16 2020 umeabot <umeabot> 3.7.18-3.mga8
+ Revision: 1531834
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 09 2019 wally <wally> 3.7.18-2.mga8
+ Revision: 1438894
- rebuild for python3.8
- drop python2 support

* Thu Feb 28 2019 daviddavid <daviddavid> 3.7.18-1.mga7
+ Revision: 1370449
- new version: 3.7.18

* Wed Jan 09 2019 daviddavid <daviddavid> 3.7.17-2.mga7
+ Revision: 1353659
- add upstream patch to fix build with new python 3.7 and cython 0.29
+ tv <tv>
- rebuild with python 3.7

* Sun Oct 21 2018 daviddavid <daviddavid> 3.7.17-1.mga7
+ Revision: 1323239
- new version: 3.7.17
- remove merged upstream patches

* Sun Sep 23 2018 umeabot <umeabot> 3.7.16-4.mga7
+ Revision: 1297294
- Mageia 7 Mass Rebuild

* Sun Apr 01 2018 daviddavid <daviddavid> 3.7.16-3.mga7
+ Revision: 1214040
- add upstream patch (P0) to fix CVE-2018-8050 (mga#22852)
- also another patch to fix an off-by-one buffer overflow

* Fri Aug 04 2017 tv <tv> 3.7.16-2.mga7
+ Revision: 1134673
- rebuild for new python

* Wed Jul 19 2017 daviddavid <daviddavid> 3.7.16-1.mga7
+ Revision: 1125231
- new version: 3.7.16
- switch to python3

* Sun Sep 18 2016 daviddavid <daviddavid> 3.7.10-1.mga6
+ Revision: 1053760
- new version: 3.7.10

* Sun Jan 24 2016 daviddavid <daviddavid> 3.7.7-1.mga6
+ Revision: 926944
- new version: 3.7.7
- update URL and Source URL
- use new python macros
- switch BRs to pkgconfig()
- remove unneeded '.la' files

* Wed Oct 15 2014 umeabot <umeabot> 3.7.4-4.mga5
+ Revision: 743482
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.4-3.mga5
+ Revision: 686459
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 3.7.4-2.mga5
+ Revision: 677712
- Mageia 5 Mass Rebuild

* Sat Jun 21 2014 malo <malo> 3.7.4-1.mga5
+ Revision: 638250
- update to 3.7.4

* Fri Oct 18 2013 umeabot <umeabot> 3.7.1-3.mga4
+ Revision: 502464
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.7.1-2.mga3
+ Revision: 345321
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 07 2012 malo <malo> 3.7.1-1.mga3
+ Revision: 257142
- new version 3.7.1

* Mon Apr 02 2012 pterjan <pterjan> 3.6.15-2.mga2
+ Revision: 227773
- Rebuild after libexpat.la removal

* Tue Jan 31 2012 malo <malo> 3.6.15-1.mga2
+ Revision: 203595
- update to version 3.6.15
- remove the warning disabling

* Sun Jan 29 2012 malo <malo> 3.6.6-1.mga2
+ Revision: 202761
- adaptation after import from Mandriva
- new version 3.6.6
- imported package afflib


* Wed Apr 21 2010 Funda Wang <fwang@mandriva.org> 3.5.5-2mdv2010.1
+ Revision: 537322
- rebuild

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 3.5.5-1mdv2010.1
+ Revision: 484163
- Update to new version 3.5.5
- Remove build fix integrated upstream

* Wed Oct 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 3.4.1-2mdv2010.0
+ Revision: 455746
- rebuild for new curl SSL backend

* Fri Sep 25 2009 Frederik Himpe <fhimpe@mandriva.org> 3.4.1-1mdv2010.0
+ Revision: 449242
- Update to new version 3.4.1
- Sync patches with Fedora
- Enable Python bindings

* Fri Sep 11 2009 Emmanuel Andry <eandry@mandriva.org> 3.3.7-1mdv2010.0
+ Revision: 438474
- New version 3.3.7

* Mon Jul 20 2009 Frederik Himpe <fhimpe@mandriva.org> 3.3.6-1mdv2010.0
+ Revision: 397999
- Add patch from Fedora to build with gcc 4.4
- Don't use rpath
- Update to new version 3.3.6

* Sun Mar 22 2009 Emmanuel Andry <eandry@mandriva.org> 3.3.4-1mdv2009.1
+ Revision: 360464
- New version 3.3.4
- disable werror for bundled lzma
- disable fuse and readline because of license incompatibility
- drop patches
- protect major
- update files list

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Dec 20 2007 Olivier Blin <oblin@mandriva.com> 2.3.0-1mdv2008.1
+ Revision: 135817
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.0-1mdv2008.0
+ Revision: 81864
- Import afflib



* Fri Sep 07 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.0-1mdv2008.0
- initial Mandriva package
